==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/Endpoint.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "capability", 
    "providerId", 
    "providerName", 
    "uri", 
    "providerResourceId"})
@JsonInclude(Include.NON_NULL)
public class Endpoint extends DirectoryObject implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.endpoint";
    }

    @JsonProperty("capability")
    protected String capability;

    @JsonProperty("providerId")
    protected String providerId;

    @JsonProperty("providerName")
    protected String providerName;

    @JsonProperty("uri")
    protected String uri;

    @JsonProperty("providerResourceId")
    protected String providerResourceId;

    protected Endpoint() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderEndpoint() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private OffsetDateTime deletedDateTime;
        private String capability;
        private String providerId;
        private String providerName;
        private String uri;
        private String providerResourceId;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder deletedDateTime(OffsetDateTime deletedDateTime) {
            this.deletedDateTime = deletedDateTime;
            this.changedFields = changedFields.add("deletedDateTime");
            return this;
        }

        public Builder capability(String capability) {
            this.capability = capability;
            this.changedFields = changedFields.add("capability");
            return this;
        }

        public Builder providerId(String providerId) {
            this.providerId = providerId;
            this.changedFields = changedFields.add("providerId");
            return this;
        }

        public Builder providerName(String providerName) {
            this.providerName = providerName;
            this.changedFields = changedFields.add("providerName");
            return this;
        }

        public Builder uri(String uri) {
            this.uri = uri;
            this.changedFields = changedFields.add("uri");
            return this;
        }

        public Builder providerResourceId(String providerResourceId) {
            this.providerResourceId = providerResourceId;
            this.changedFields = changedFields.add("providerResourceId");
            return this;
        }

        public Endpoint build() {
            Endpoint _x = new Endpoint();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.endpoint";
            _x.id = id;
            _x.deletedDateTime = deletedDateTime;
            _x.capability = capability;
            _x.providerId = providerId;
            _x.providerName = providerName;
            _x.uri = uri;
            _x.providerResourceId = providerResourceId;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="capability")
    @JsonIgnore
    public Optional<String> getCapability() {
        return Optional.ofNullable(capability);
    }

    public Endpoint withCapability(String capability) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("capability");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.capability = capability;
        return _x;
    }

    @Property(name="providerId")
    @JsonIgnore
    public Optional<String> getProviderId() {
        return Optional.ofNullable(providerId);
    }

    public Endpoint withProviderId(String providerId) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerId = providerId;
        return _x;
    }

    @Property(name="providerName")
    @JsonIgnore
    public Optional<String> getProviderName() {
        return Optional.ofNullable(providerName);
    }

    public Endpoint withProviderName(String providerName) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerName = providerName;
        return _x;
    }

    @Property(name="uri")
    @JsonIgnore
    public Optional<String> getUri() {
        return Optional.ofNullable(uri);
    }

    public Endpoint withUri(String uri) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("uri");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.uri = uri;
        return _x;
    }

    @Property(name="providerResourceId")
    @JsonIgnore
    public Optional<String> getProviderResourceId() {
        return Optional.ofNullable(providerResourceId);
    }

    public Endpoint withProviderResourceId(String providerResourceId) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerResourceId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerResourceId = providerResourceId;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Endpoint patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Endpoint _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Endpoint put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Endpoint _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Endpoint _copy() {
        Endpoint _x = new Endpoint();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.deletedDateTime = deletedDateTime;
        _x.capability = capability;
        _x.providerId = providerId;
        _x.providerName = providerName;
        _x.uri = uri;
        _x.providerResourceId = providerResourceId;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Endpoint[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("deletedDateTime=");
        b.append(this.deletedDateTime);
        b.append(", ");
        b.append("capability=");
        b.append(this.capability);
        b.append(", ");
        b.append("providerId=");
        b.append(this.providerId);
        b.append(", ");
        b.append("providerName=");
        b.append(this.providerName);
        b.append(", ");
        b.append("uri=");
        b.append(this.uri);
        b.append(", ");
        b.append("providerResourceId=");
        b.append(this.providerResourceId);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/Endpoint.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.time.OffsetDateTime;
import java.util.Optional;

@JsonPropertyOrder({
    "@odata.type", 
    "capability", 
    "providerId", 
    "providerName", 
    "providerResourceId", 
    "uri"})
@JsonInclude(Include.NON_NULL)
public class Endpoint extends DirectoryObject implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.endpoint";
    }

    @JsonProperty("capability")
    protected String capability;

    @JsonProperty("providerId")
    protected String providerId;

    @JsonProperty("providerName")
    protected String providerName;

    @JsonProperty("providerResourceId")
    protected String providerResourceId;

    @JsonProperty("uri")
    protected String uri;

    protected Endpoint() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderEndpoint() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private OffsetDateTime deletedDateTime;
        private String capability;
        private String providerId;
        private String providerName;
        private String providerResourceId;
        private String uri;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder deletedDateTime(OffsetDateTime deletedDateTime) {
            this.deletedDateTime = deletedDateTime;
            this.changedFields = changedFields.add("deletedDateTime");
            return this;
        }

        public Builder capability(String capability) {
            this.capability = capability;
            this.changedFields = changedFields.add("capability");
            return this;
        }

        public Builder providerId(String providerId) {
            this.providerId = providerId;
            this.changedFields = changedFields.add("providerId");
            return this;
        }

        public Builder providerName(String providerName) {
            this.providerName = providerName;
            this.changedFields = changedFields.add("providerName");
            return this;
        }

        public Builder providerResourceId(String providerResourceId) {
            this.providerResourceId = providerResourceId;
            this.changedFields = changedFields.add("providerResourceId");
            return this;
        }

        public Builder uri(String uri) {
            this.uri = uri;
            this.changedFields = changedFields.add("uri");
            return this;
        }

        public Endpoint build() {
            Endpoint _x = new Endpoint();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.endpoint";
            _x.id = id;
            _x.deletedDateTime = deletedDateTime;
            _x.capability = capability;
            _x.providerId = providerId;
            _x.providerName = providerName;
            _x.providerResourceId = providerResourceId;
            _x.uri = uri;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="capability")
    @JsonIgnore
    public Optional<String> getCapability() {
        return Optional.ofNullable(capability);
    }

    public Endpoint withCapability(String capability) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("capability");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.capability = capability;
        return _x;
    }

    @Property(name="providerId")
    @JsonIgnore
    public Optional<String> getProviderId() {
        return Optional.ofNullable(providerId);
    }

    public Endpoint withProviderId(String providerId) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerId = providerId;
        return _x;
    }

    @Property(name="providerName")
    @JsonIgnore
    public Optional<String> getProviderName() {
        return Optional.ofNullable(providerName);
    }

    public Endpoint withProviderName(String providerName) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerName");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerName = providerName;
        return _x;
    }

    @Property(name="providerResourceId")
    @JsonIgnore
    public Optional<String> getProviderResourceId() {
        return Optional.ofNullable(providerResourceId);
    }

    public Endpoint withProviderResourceId(String providerResourceId) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("providerResourceId");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.providerResourceId = providerResourceId;
        return _x;
    }

    @Property(name="uri")
    @JsonIgnore
    public Optional<String> getUri() {
        return Optional.ofNullable(uri);
    }

    public Endpoint withUri(String uri) {
        Endpoint _x = _copy();
        _x.changedFields = changedFields.add("uri");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.endpoint");
        _x.uri = uri;
        return _x;
    }

    public Endpoint withUnmappedField(String name, Object value) {
        Endpoint _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Endpoint patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        Endpoint _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public Endpoint put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        Endpoint _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private Endpoint _copy() {
        Endpoint _x = new Endpoint();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.deletedDateTime = deletedDateTime;
        _x.capability = capability;
        _x.providerId = providerId;
        _x.providerName = providerName;
        _x.providerResourceId = providerResourceId;
        _x.uri = uri;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("Endpoint[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("deletedDateTime=");
        b.append(this.deletedDateTime);
        b.append(", ");
        b.append("capability=");
        b.append(this.capability);
        b.append(", ");
        b.append("providerId=");
        b.append(this.providerId);
        b.append(", ");
        b.append("providerName=");
        b.append(this.providerName);
        b.append(", ");
        b.append("providerResourceId=");
        b.append(this.providerResourceId);
        b.append(", ");
        b.append("uri=");
        b.append(this.uri);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
